==> mahara-1.9.1.txz: usr/local/www/mahara/artefact/blog/lang/en.utf8/artefact.blog.php <==
<?php
/**
 *
 * @package    mahara
 * @subpackage lang
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL version 3 or later
 * @copyright  For copyright information on Mahara, please see the README file distributed with this software.
 *
 */

defined('INTERNAL') || die();

$string['pluginname'] = 'Journals';

$string['blog'] = 'Journal';
$string['blogs'] = 'Journals';
$string['addblog'] = 'Create journal';
$string['addpost'] = 'New entry';
$string['alignment'] = 'Alignment';
$string['allowcommentsonpost'] = 'Allow comments on your entry.';
$string['allposts'] = 'All entries';
$string['attach'] = 'Attach';
$string['attachedfilelistloaded'] = 'Attached file list loaded';
$string['attachedfiles'] = 'Attached files';
$string['attachment'] = 'Attachment';
$string['attachments'] = 'Attachments';
$string['blogcopiedfromanotherview'] = 'Note: This block has been copied from another page. You may move it around or remove it, but you cannot change what %s is in it.';
$string['blogdesc'] = 'Description';
$string['blogdescdesc'] = 'e.g., ‘A record of Jill\'s experiences and reflections’.';
$string['blogdoesnotexist'] = 'You are trying to access a journal that does not exist';
$string['blogpostdoesnotexist'] = 'You are trying to access a journal entry that does not exist';
$string['blogpost'] = 'Journal entry';
$string['blogdeleted'] = 'Journal deleted';
$string['blogpostdeleted'] = 'Journal entry deleted';
$string['blogpostpublished'] = 'Journal entry published';
$string['blogpostunpublished'] = 'Journal entry unpublished';
$string['blogpostsaved'] = 'Journal entry saved';
$string['blogsettings'] = 'Journal settings';
$string['blogtitle'] = 'Title';
$string['blogtitledesc'] = 'e.g., ‘Jill’s Nursing Practicum Journal’.';
$string['border'] = 'Border';
$string['by'] = 'by';
$string['cancel'] = 'Cancel';
$string['createandpublishdesc'] = 'This will create the journal entry and make it available to others.';
$string['createasdraftdesc'] = 'This will create the journal entry, but it will not become available to others until you choose to publish it.';
$string['createblog'] = 'Create journal';
$string['dataimportedfrom'] = 'Data imported from %s';
$string['defaultblogtitle'] = '%s\'s Journal';
$string['deleteblog?'] = 'Are you sure you want to delete this journal?';
$string['deletebloghaspost?'] = array(
    0 => 'This journal contains 1 entry. Are you sure you want to delete this journal?',
    1 => 'This journal contains %d entries. Are you sure you want to delete this journal?'
);
$string['deletebloghasview?'] = array(
    0 => 'This journal contains entries that are used in 1 page. Are you sure you want to delete this journal?',
    1 => 'This journal contains entries that are used in %d pages. Are you sure you want to delete this journal?'
);
$string['deleteblogpost?'] = 'Are you sure you want to delete this entry?';
$string['description'] = 'Description';
$string['dimensions'] = 'Dimensions';
$string['draft'] = 'Draft';
$string['edit'] = 'Edit';
$string['editblogpost'] = 'Edit journal entry';
$string['entriesimportedfromleapexport'] = 'Entries imported from a LEAP export that were not able to be imported elsewhere';
$string['errorsavingattachments'] = 'An error occurred while saving journal entry attachments';
$string['horizontalspace'] = 'Horizontal space';
$string['insert'] = 'Insert';
$string['insertimage'] = 'Insert image';
$string['moreoptions'] = 'More options';
$string['mustspecifytitle'] = 'You must specify a title for your entry';
$string['mustspecifycontent'] = 'You must specify some content for your entry';
$string['name'] = 'Name';
$string['newattachmentsexceedquota'] = 'The total size of the new files that you have uploaded to this entry would exceed your quota. You may be able to save the entry if you remove some of the attachments you have just added.';
$string['newblog'] = 'New journal';
$string['newblogpost'] = 'New journal entry in journal "%s"';
$string['newerposts'] = 'Newer entries';
$string['nodefaultblogfound'] = 'No default journal found. This is a bug in the system. To fix it, you need to enable the multiple journals option on the <a href="%saccount/index.php">account settings</a> page.';
$string['nopostsyet'] = 'No entries yet.';
$string['noimageshavebeenattachedtothispost'] = 'No images have been attached to this entry. You need to upload or attach an image to the entry before you can insert it.';
$string['nofilesattachedtothispost'] = 'No attached files';
$string['noresults'] = 'No journal entries found';
$string['olderposts'] = 'Older entries';
$string['post'] = 'entry';
$string['postbody'] = 'Entry';
$string['postbodydesc'] = ' ';
$string['postedon'] = 'Posted on';
$string['postedbyon'] = 'Posted by %s on %s';
$string['posttitle'] = 'Title';
$string['posts'] = 'entries';
$string['nposts'] = array(
    '1 entry',
    '%s entries',
);

$string['publish'] = 'Publish';
$string['unpublish'] = 'Unpublish';
$string['publishfailed'] = 'An error occurred. Your entry was not published.';
$string['publishblogpost?'] = 'Are you sure you want to publish this entry?';
$string['published'] = 'Published';
$string['remove'] = 'Remove';
$string['save'] = 'Save';
$string['saveandpublish'] = 'Save and publish';
$string['saveasdraft'] = 'Save as draft';
$string['savepost'] = 'Save entry';
$string['savesettings'] = 'Save settings';
$string['settings'] = 'Settings';
$string['thisisdraft'] = 'This entry is a draft';
$string['thisisdraftdesc'] = 'When your entry is a draft, no one except you can see it.';
$string['title'] = 'Title';
$string['update'] = 'Update';
$string['verticalspace'] = 'Vertical space';
$string['viewblog'] = 'View journal';
$string['youarenottheownerofthisblog'] = 'You are not the owner of this journal.';
$string['youarenottheownerofthisblogpost'] = 'You are not the owner of this journal entry.';
$string['cannotdeleteblogpost'] = 'An error occurred removing this journal entry.';

$string['baseline'] = 'Baseline';
$string['top'] = 'Top';
$string['middle'] = 'Middle';
$string['bottom'] = 'Bottom';
$string['texttop'] = 'Text top';
$string['textbottom'] = 'Text bottom';
$string['left'] = 'Left';
$string['right'] = 'Right';
$string['src'] = 'Image URL';
$string['image_list'] = 'Attached image';
$string['alt'] = 'Description';

$string['copyfull'] = 'Others will get their own copy of your %s';
$string['copyreference'] = 'Others may display your %s in their page';
$string['copynocopy'] = 'Skip this block entirely when copying the page';

$string['viewposts'] = 'Copied entries (%s)';
$string['postscopiedfromview'] = 'Entries copied from %s';

$string['youhavenoblogs'] = 'You have no journals.';
$string['youhaveoneblog'] = 'You have 1 journal.';
$string['youhaveblogs'] = 'You have %s journals.';

$string['feedsnotavailable'] = 'Feeds are not available for this artefact type.';
$string['feedrights'] = 'Copyright %s.';

$string['enablemultipleblogstext'] = 'You have one journal. If you would like to start a second one, enable the multiple journals option on the <a href="%saccount/index.php">account settings</a> page.';
$string['hiddenblogsnotification'] = 'Additional journal(s) have been made for you, but your account does not have the multiple journals option activated. You can enable it on the <a href="%saccount/index.php">account settings</a> page.';

$string['shortcutaddpost'] = 'Add a new entry to';
$string['shortcutgo'] = 'Go';
$string['shortcutnewentry'] = 'New entry';

$string['duplicatedblog'] = 'Duplicated journal';
$string['existingblogs'] = 'Existing journals';
$string['duplicatedpost'] = 'Duplicated journal entry';
$string['existingposts'] = 'Existing journal entries';

$string['progress_blog'] = 'Add a journal';
$string['progress_blogpost'] = array(
    'Add 1 entry to a journal',
    'Add %s entries to a journal',
);

==> mahara-15.04.0_1.txz: usr/local/www/mahara/artefact/blog/lang/en.utf8/artefact.blog.php <==
<?php
/**
 *
 * @package    mahara
 * @subpackage lang
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL version 3 or later
 * @copyright  For copyright information on Mahara, please see the README file distributed with this software.
 *
 */

defined('INTERNAL') || die();

$string['pluginname'] = 'Journals';

$string['blog'] = 'Journal';
$string['blogs'] = 'Journals';
$string['addblog'] = 'Create journal';
$string['addpost'] = 'New entry';
$string['alignment'] = 'Alignment';
$string['allowcommentsonpost'] = 'Allow comments on your entry.';
$string['allposts'] = 'All entries';
$string['attach'] = 'Attach';
$string['attachedfilelistloaded'] = 'Attached file list loaded';
$string['attachedfiles'] = 'Attached files';
$string['attachment'] = 'Attachment';
$string['attachments'] = 'Attachments';
$string['blogcopiedfromanotherview'] = 'Note: This block has been copied from another page. You may move it around or remove it, but you cannot change what %s is in it.';
$string['blogdesc'] = 'Description';
$string['blogdescdesc'] = 'e.g., ‘A record of Jill\'s experiences and reflections’.';
$string['blogdoesnotexist'] = 'You are trying to access a journal that does not exist';
$string['blogpostdoesnotexist'] = 'You are trying to access a journal entry that does not exist';
$string['blogpost'] = 'Journal entry';
$string['blogdeleted'] = 'Journal deleted';
$string['blogpostdeleted'] = 'Journal entry deleted';
$string['blogpostpublished'] = 'Journal entry published';
$string['blogpostunpublished'] = 'Journal entry unpublished';
$string['blogpostsaved'] = 'Journal entry saved';
$string['blogsettings'] = 'Journal settings';
$string['blogtitle'] = 'Title';
$string['blogtitledesc'] = 'e.g., ‘Jill’s Nursing Practicum Journal’.';
$string['border'] = 'Border';
$string['by'] = 'by';
$string['cancel'] = 'Cancel';
$string['createandpublishdesc'] = 'This will create the journal entry and make it available to others.';
$string['createasdraftdesc'] = 'This will create the journal entry, but it will not become available to others until you choose to publish it.';
$string['createblog'] = 'Create journal';
$string['dataimportedfrom'] = 'Data imported from %s';
$string['defaultblogtitle'] = '%s\'s Journal';
$string['deleteblog?'] = 'Are you sure you want to delete this journal?';
$string['deletebloghaspost?'] = array(
    0 => 'This journal contains 1 entry. Are you sure you want to delete this journal?',
    1 => 'This journal contains %d entries. Are you sure you want to delete this journal?'
);
$string['deletebloghasview?'] = array(
    0 => 'This journal contains entries that are used in 1 page. Are you sure you want to delete this journal?',
    1 => 'This journal contains entries that are used in %d pages. Are you sure you want to delete this journal?'
);
$string['deleteblogpost?'] = 'Are you sure you want to delete this entry?';
$string['description'] = 'Description';
$string['dimensions'] = 'Dimensions';
$string['draft'] = 'Draft';
$string['edit'] = 'Edit';
$string['editblogpost'] = 'Edit journal entry';
$string['entriesimportedfromleapexport'] = 'Entries imported from a Leap2A export that were not able to be imported elsewhere';
$string['errorsavingattachments'] = 'An error occurred while saving journal entry attachments';
$string['horizontalspace'] = 'Horizontal space';
$string['insert'] = 'Insert';
$string['insertimage'] = 'Insert image';
$string['moreoptions'] = 'More options';
$string['mustspecifytitle'] = 'You must specify a title for your entry';
$string['mustspecifycontent'] = 'You must specify some content for your entry';
$string['name'] = 'Name';
$string['newattachmentsexceedquota'] = 'The total size of the new files that you have uploaded to this entry would exceed your quota. You may be able to save the entry if you remove some of the attachments you have just added.';
$string['newblog'] = 'New journal';
$string['newblogpost'] = 'New journal entry in journal "%s"';
$string['newerposts'] = 'Newer entries';
$string['nodefaultblogfound'] = 'No default journal found. This is a bug in the system. To fix it, you need to enable the multiple journals option on the <a href="%saccount/index.php">account settings</a> page.';
$string['nopostsyet'] = 'No entries yet.';
$string['noimageshavebeenattachedtothispost'] = 'No images have been attached to this entry. You need to upload or attach an image to the entry before you can insert it.';
$string['nofilesattachedtothispost'] = 'No attached files';
$string['noresults'] = 'No journal entries found';
$string['olderposts'] = 'Older entries';
$string['post'] = 'entry';
$string['postbody'] = 'Entry';
$string['postbodydesc'] = ' ';
$string['postedon'] = 'Posted on';
$string['postedbyon'] = 'Posted by %s on %s';
$string['posttitle'] = 'Title';
$string['posts'] = 'entries';
$string['nposts'] = array(
    '1 entry',
    '%s entries',
);

$string['publish'] = 'Publish';
$string['publishit'] = 'Publish it.';
$string['unpublish'] = 'Unpublish';
$string['publishfailed'] = 'An error occurred. Your entry was not published.';
$string['publishblogpost?'] = 'Are you sure you want to publish this entry?';
$string['published'] = 'Published';
$string['remove'] = 'Remove';
$string['save'] = 'Save';
$string['saveandpublish'] = 'Save and publish';
$string['saveasdraft'] = 'Save as draft';
$string['savepost'] = 'Save entry';
$string['savesettings'] = 'Save settings';
$string['settings'] = 'Settings';
$string['thisisdraft'] = 'This entry is a draft';
$string['thisisdraftdesc'] = 'When your entry is a draft, no one except you can see it.';
$string['title'] = 'Title';
$string['update'] = 'Update';
$string['verticalspace'] = 'Vertical space';
$string['viewblog'] = 'View journal';
$string['youarenottheownerofthisblog'] = 'You are not the owner of this journal.';
$string['youarenottheownerofthisblogpost'] = 'You are not the owner of this journal entry.';
$string['cannotdeleteblogpost'] = 'An error occurred removing this journal entry.';

$string['baseline'] = 'Baseline';
$string['top'] = 'Top';
$string['middle'] = 'Middle';
$string['bottom'] = 'Bottom';
$string['texttop'] = 'Text top';
$string['textbottom'] = 'Text bottom';
$string['left'] = 'Left';
$string['right'] = 'Right';
$string['src'] = 'Image URL';
$string['image_list'] = 'Attached image';
$string['alt'] = 'Description';

$string['copyfull'] = 'Others will get their own copy of your %s';
$string['copyreference'] = 'Others may display your %s in their page';
$string['copynocopy'] = 'Skip this block entirely when copying the page';

$string['viewposts'] = 'Copied entries (%s)';
$string['postscopiedfromview'] = 'Entries copied from %s';

$string['youhavenoblogs'] = 'You have no journals.';
$string['youhaveoneblog'] = 'You have 1 journal.';
$string['youhaveblogs'] = 'You have %s journals.';

$string['feedsnotavailable'] = 'Feeds are not available for this artefact type.';
$string['feedrights'] = 'Copyright %s.';

$string['enablemultipleblogstext'] = 'You have one journal. If you would like to start a second one, enable the multiple journals option on the <a href="%saccount/index.php">account settings</a> page.';
$string['hiddenblogsnotification'] = 'Additional journal(s) have been made for you, but your account does not have the multiple journals option activated. You can enable it on the <a href="%saccount/index.php">account settings</a> page.';

$string['shortcutaddpost'] = 'Add a new entry to';
$string['shortcutgo'] = 'Go';
$string['shortcutnewentry'] = 'New entry';

$string['duplicatedblog'] = 'Duplicated journal';
$string['existingblogs'] = 'Existing journals';
$string['duplicatedpost'] = 'Duplicated journal entry';
$string['existingposts'] = 'Existing journal entries';

$string['progress_blog'] = 'Add a journal';
$string['progress_blogpost'] = array(
    'Add 1 entry to a journal',
    'Add %s entries to a journal',
);
$string['notpublishedblogpost'] = 'This journal entry has not been published yet.';
